<?php

define('MODULE_PAYMENT_PERFECTMONEY_RM', '2');

if (IS_ADMIN_FLAG === true) {
  include_once(DIR_FS_CATALOG_MODULES . 'payment/perfectmoney/perfectmoney_functions.php');
  include_once(DIR_FS_CATALOG . 'includes/extra_configures/perfectmoney_defines.php');
} else {
  include_once(DIR_WS_MODULES . 'payment/perfectmoney/perfectmoney_functions.php');
}
/**
 * Perfect Money payment method class
 *
 */
class perfectmoney extends base {
  /**
   * string repesenting the payment method
   *
   * @var string
   */
  var $code;
  /**
   * $title is the displayed name for this payment method
   *
   * @var string
    */
  var $title;
  /**
   * $description is a soft name for this payment method
   *
   * @var string
    */
  var $description;
  /**
   * $enabled determines whether this module shows or not... in catalog.
   *
   * @var boolean
    */
  var $enabled;
  /**
    * constructor
    *
    * @param int $perfectmoney_id
    * @return perfectmoney
    */
  function perfectmoney($perfectmoney_id = '') {
    global $order, $messageStack;
    $this->code = 'perfectmoney';
    if (IS_ADMIN_FLAG === true) {
      $this->title = MODULE_PAYMENT_PERFECTMONEY_TEXT_ADMIN_TITLE; // Payment module title in Admin
    } else {
      $this->title = MODULE_PAYMENT_PERFECTMONEY_TEXT_CATALOG_TITLE; // Payment module title in Catalog
    }
    $this->description = MODULE_PAYMENT_PERFECTMONEY_TEXT_DESCRIPTION;
    $this->sort_order = MODULE_PAYMENT_PERFECTMONEY_SORT_ORDER;
    $this->enabled = ((MODULE_PAYMENT_PERFECTMONEY_STATUS == 'True') ? true : false);
    if ((int)MODULE_PAYMENT_PERFECTMONEY_ORDER_STATUS_ID > 0) {
      $this->order_status = MODULE_PAYMENT_PERFECTMONEY_ORDER_STATUS_ID;
    }
    if (is_object($order)) $this->update_status();
	$this->form_action_url = 'https://perfectmoney.com/api/step1.asp';
  }
  /**
   * calculate zone matches and flag settings to determine whether this module should display to customers or not
    *
    */
  function update_status() {
    global $order, $db;

    if ( ($this->enabled == true) && ((int)MODULE_PAYMENT_PERFECTMONEY_ZONE > 0) ) {
      $check_flag = false;
      $check_query = $db->Execute("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_PAYMENT_PERFECTMONEY_ZONE . "' and zone_country_id = '" . $order->billing['country']['id'] . "' order by zone_id");
      while (!$check_query->EOF) {
        if ($check_query->fields['zone_id'] < 1) {
          $check_flag = true;
          break;
        } elseif ($check_query->fields['zone_id'] == $order->billing['zone_id']) {
          $check_flag = true;
          break;
        }
        $check_query->MoveNext();
      }

      if ($check_flag == false) {
        $this->enabled = false;
      }
    }
  }
  /**
   * JS validation which does error-checking of data-entry if this module is selected for use
   * (Number, Owner, and CVV Lengths)
   *
   * @return string
    */
  function javascript_validation() {
    return false;
  }
  /**
   * Displays Credit Card Information Submission Fields on the Checkout Payment Page
   * In the case of Perfect Money, this only displays the Perfect Money title
   *
   * @return array
    */
  function selection() {
    return array('id' => $this->code,
                 'module' => $this->title);
  }
  /**
   * Normally evaluates the Credit Card Type for acceptance and the validity of the Credit Card Number & Expiration Date
   * Since Perfect Money module is not collecting info, it simply skips this step.
   *
   * @return boolean
   */
  function pre_confirmation_check() {

	return false;
      
  }
  /**
   * Display Credit Card Information on the Checkout Confirmation Page
   * Since none is collected for Perfect Money before forwarding to payments page, this is skipped
   *
   * @return boolean
    */
  function confirmation() {
    return false;
  }
  
  /**
   * Build the data and actions to process when the "Submit" button is pressed on the order-confirmation screen.
   * This sends the data to the payment gateway for processing.
   * (These are hidden fields on the checkout confirmation page)
   *
   * @return string
    */
  function process_button() {
	  
	global $db, $order, $currencies, $currency;
    
    $this->totalsum = $order->info['total'];
		$cOrderTotal = $order->info['total'];
		if ($order->info['currency'] != MODULE_PAYMENT_PERFECTMONEY_CURRENCY) {
			$cOrderTotal = $currencies->get_value(MODULE_PAYMENT_PERFECTMONEY_CURRENCY) * ($order->info['total'] / $currencies->get_value($order->info['currency']));
		}
                
                
    $order_total_modules = new order_total();
    $order_totals = $order_total_modules->process();
    $insert_id = $order->create($order_totals);
    
    $db->Execute("update " . TABLE_ORDERS . "
                              set orders_status = " . MODULE_PAYMENT_PERFECTMONEY_PROCESSING_STATUS_ID . "
                              where orders_id = '" . $insert_id . "'");
    
	// payment form

	$perfectmoney_handler=HTTP_SERVER.DIR_WS_CATALOG.'perfectmoney_handler.php';

	$perfectmoney_form='<input type="hidden" name="PAYEE_ACCOUNT" value="'.MODULE_PAYMENT_PERFECTMONEY_ACCOUNT.'"/>
	<input type="hidden" name="PAYEE_NAME" value="'.STORE_NAME.'"/>
	<input type="hidden" name="PAYMENT_AMOUNT" value="'.number_format($cOrderTotal, 2, '.', '').'"/>
	<input type="hidden" name="PAYMENT_UNITS" value="'.MODULE_PAYMENT_PERFECTMONEY_CURRENCY.'"/>
	<input type="hidden" name="PAYMENT_ID" value="'.$insert_id.'"/>
	<input type="hidden" name="STATUS_URL" value="'.$perfectmoney_handler.'"/>
	<input type="hidden" name="PAYMENT_URL" value="'.zen_href_link(FILENAME_CHECKOUT_SUCCESS, '', 'SSL').'"/>
	<input type="hidden" name="PAYMENT_URL_METHOD" value="LINK"/>
	<input type="hidden" name="NOPAYMENT_URL" value="'.zen_href_link(FILENAME_CHECKOUT_PAYMENT, '', 'SSL').'"/>
	<input type="hidden" name="NOPAYMENT_URL_METHOD" value="LINK"/>
	<input type="hidden" name="SUGGESTED_MEMO" value="'.MODULE_PAYMENT_PERFECTMONEY_PURCHASE_DECRIPTION_TITLE.'"/>';
      
    return $perfectmoney_form;
    
  }

  /**
    * Checks referrer
    *
    * @param string $zf_domain
    * @return boolean
    */
  function check_referrer($zf_domain) {
    return true;
  }
  /**
    * Build admin-page components
    *
    * @param int $zf_order_id
    * @return string
    */
  function admin_notification($zf_order_id) {
    global $db;
    $output = '';
    $sql = "select * from " . TABLE_PERFECTMONEY . " where order_id = '" . (int)$zf_order_id . "' order by perfectmoney_id DESC LIMIT 1";
    $pm = $db->Execute($sql);
    if ($pm->RecordCount() > 0) require(DIR_FS_CATALOG. DIR_WS_MODULES . 'payment/perfectmoney/perfectmoney_admin_notification.php');
    return $output;
  }
  /**
   * Post-processing activities
   *
   * @return boolean
    */
  function after_process() {
    $_SESSION['order_created'] = '';
    return false;
  }
  /**
   * Used to display error message details
   *
   * @return boolean
    */
  function output_error() {
    return false;
  }
  /**
   * Check to see whether module is installed
   *
   * @return boolean
    */
  function check() {
    global $db;
    if (!isset($this->_check)) {
      $check_query = $db->Execute("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_PERFECTMONEY_STATUS'");
      $this->_check = $check_query->RecordCount();
    }
    return $this->_check;
  }
  /**
   * Install the payment module and its configuration settings
    *
    */
  function install() {
    global $db;
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Enable Perfect Money module', 'MODULE_PAYMENT_PERFECTMONEY_STATUS', 'True', 'Do you want to enable Perfect Money payment method?', '6', '44', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now())");  
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Perfect Money account', 'MODULE_PAYMENT_PERFECTMONEY_ACCOUNT', '', 'Perfect Money merchant account ID. For example, U12345678', '6', '44', now())");
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Currencies', 'MODULE_PAYMENT_PERFECTMONEY_CURRENCY', 'USD', 'Which currency do you want to accept payments in? Currency must correspond to account type you selected.', '6', '44', 'zen_cfg_select_option(array(\'USD\', \'EUR\'), ', now())");
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Alternate PassPhrase', 'MODULE_PAYMENT_PERFECTMONEY_PASSPHRASE', '', 'Alternate PassPhrase can be found and set under Settings section of your PM account.', '6', '44', now())");
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Payment Zone', 'MODULE_PAYMENT_PERFECTMONEY_ZONE', '0', 'If a zone is selected, only enable this payment method for that zone.', '6', '44', 'zen_get_zone_class_title', 'zen_cfg_pull_down_zone_classes(', now())");
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, use_function, date_added) values ('Set Pending Notification Status', 'MODULE_PAYMENT_PERFECTMONEY_PROCESSING_STATUS_ID', '" . DEFAULT_ORDERS_STATUS_ID .  "', 'Set the status of orders made with this payment module that are not yet completed to this value<br />(\'Pending\' recommended)', '6', '44', 'zen_cfg_pull_down_order_statuses(', 'zen_get_order_status_name', now())");
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, use_function, date_added) values ('Set Order Status', 'MODULE_PAYMENT_PERFECTMONEY_ORDER_STATUS_ID', '2', 'Set the status of orders made with this payment module that have completed payment to this value<br />(\'Processing\' recommended)', '6', '44', 'zen_cfg_pull_down_order_statuses(', 'zen_get_order_status_name', now())");
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Sort order of display', 'MODULE_PAYMENT_PERFECTMONEY_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '44', now())");

    // Perfect Money testing options go here
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Debug Mode', 'MODULE_PAYMENT_PERFECTMONEY_DEBUG', 'Off', 'Enable debug logging? <br /><strong>Leave OFF for normal operation.</strong>', '6', '44', 'zen_cfg_select_option(array(\'On\', \'Off\'), ', now())");

    $this->notify('NOTIFY_PAYMENT_PERFECTMONEY_INSTALLED');
  }
  /**
   * Remove the module and all its settings
    *
    */
  function remove() {
    global $db;
    $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key LIKE 'MODULE\_PAYMENT\_PERFECTMONEY%'");
    $this->notify('NOTIFY_PAYMENT_PERFECTMONEY_UNINSTALLED');
  }
  /**
   * Internal list of configuration keys used for configuration of the module
   *
   * @return array
    */
  function keys() {
    $keys_list = array(
                       'MODULE_PAYMENT_PERFECTMONEY_STATUS',
                       'MODULE_PAYMENT_PERFECTMONEY_SORT_ORDER',
                       'MODULE_PAYMENT_PERFECTMONEY_ACCOUNT', 
                       'MODULE_PAYMENT_PERFECTMONEY_CURRENCY', 
                       'MODULE_PAYMENT_PERFECTMONEY_PASSPHRASE',
                       'MODULE_PAYMENT_PERFECTMONEY_ZONE',
                       'MODULE_PAYMENT_PERFECTMONEY_PROCESSING_STATUS_ID',
                       'MODULE_PAYMENT_PERFECTMONEY_ORDER_STATUS_ID',
                       'MODULE_PAYMENT_PERFECTMONEY_SORT_ORDER');

    // testing/debug options go here:
    $keys_list[]='MODULE_PAYMENT_PERFECTMONEY_DEBUG';
    return $keys_list;
  }

  function before_process() {
    
  }

}